Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(234)

Unified Diff: sdk/lib/async/stream_controller.dart

Issue 14103010: Change hasSubscribers to hasListener. (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Addressed comments. Created 7 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « sdk/lib/async/stream.dart ('k') | sdk/lib/async/stream_impl.dart » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: sdk/lib/async/stream_controller.dart
diff --git a/sdk/lib/async/stream_controller.dart b/sdk/lib/async/stream_controller.dart
index 02f197c958677f6ae2ecc854b2dba656183dc9aa..24a9999b654b0c1a29700d3ea9e1b4155dd9e140 100644
--- a/sdk/lib/async/stream_controller.dart
+++ b/sdk/lib/async/stream_controller.dart
@@ -58,7 +58,7 @@ class StreamController<T> extends EventSink<T> {
*
* The [onSubscriptionStateChange] function is called when the stream
* receives its first listener or loses its last. The current subscription
* state can be read from [hasSubscribers]. Ignored if [:null:].
*/
StreamController.broadcast({void onPauseStateChange(),
void onSubscriptionStateChange()})
@@ -77,7 +77,7 @@ class StreamController<T> extends EventSink<T> {
*
* The [onSubscriptionStateChange] function is called when the stream
* receives its first listener or loses its last. The current subscription
* state can be read from [hasSubscribers]. Ignored if [:null:].
*/
StreamController({void onPauseStateChange(),
void onSubscriptionStateChange()})
@@ -101,7 +101,7 @@ class StreamController<T> extends EventSink<T> {
bool get isPaused => stream._isInputPaused;
/** Whether there are currently any subscribers on this [Stream]. */
- bool get hasSubscribers => stream._hasSubscribers;
+ bool get hasListener => stream._hasListener;
/**
* Send or queue a data event.
« no previous file with comments | « sdk/lib/async/stream.dart ('k') | sdk/lib/async/stream_impl.dart » ('j') | no next file with comments »
@@ -58,7 +58,7 @@ class StreamController<T> extends EventSink<T> {
* The [onSubscriptionStateChange] function is called when the stream
* receives its first listener or loses its last. The current subscription
- * state can be read from [hasSubscribers]. Ignored if [:null:].
+ * state can be read from [hasListener]. Ignored if [:null:].
*/
StreamController.broadcast({void onPauseStateChange(),
@@ -77,7 +77,7 @@ class StreamController<T> extends EventSink<T> {
* The [onSubscriptionStateChange] function is called when the stream
* receives its first listener or loses its last. The current subscription
- * state can be read from [hasSubscribers]. Ignored if [:null:].
+ * state can be read from [hasListener]. Ignored if [:null:].
*/
StreamController({void onPauseStateChange(),

Powered by Google App Engine
This is Rietveld 408576698